Module: Devise::Models::ValidatableWithPersonEmail

Extended by:
ActiveSupport::Concern
Defined in:
lib/devise/models/validatable_with_person_email.rb

Overview

ValidatableWithPersonEmail

A re-implementation of Devise::Models::Validatable, but instead of expecting the email field to be in the authenticatable model, is located instead in the Person associated model

Defined Under Namespace

Modules: ClassMethods